@@ -3,9 +3,14 @@ from abc import abstractmethod
 from data2code_sdk.plugin.raw_data import RawData
 from data2code_sdk.plugin.parsed_result import BaseParsedData
 from typing import List
+from data2code_sdk.plugin.plugin_type import PluginType
 
 
 class IParserPlugin(IPlugin):
+    @staticmethod
+    def get_plugin_type():
+        return PluginType.PARSER
+
     """
     data2code 应用的分析插件的接口类，规定了必须要实现的接口
     """
