@@ -14,12 +14,41 @@ class ConfigLoadedSignal(Signal):
         super().dispatch(configs)
 
 
+@singleton
+class SaveConfigSignal(Signal):
+    """
+    请求保存配置的信号
+    收到此信号后，APP会保存传递的配置
+    """
+    def dispatch(self, config: ProjectConfig):
+        super().dispatch(config)
+
+
+@singleton
+class SaveConfigFinishSignal(Signal):
+    """
+    保存配置完成时的信号
+    """
+    def dispatch(self):
+        super().dispatch()
+
+
+@singleton
+class UpdateConfigsSignal(Signal):
+    """
+    配置有更新时的信号
+    """
+    def dispatch(self, configs: List[ProjectConfig]):
+        super().dispatch(configs)
+
+
 @singleton
 class StartToProcessSignal(Signal):
     """
     通知开始进行处理（数据）的信号
     """
-    pass
+    def dispatch(self, project_name: str=None):
+        super().dispatch(project_name)
 
 
 @singleton
